@@ -63,7 +63,7 @@ class PlatformTemplateContent(PluginTemplateExtension):
                 },
             )
         else:
-            drives_id = Drive.objects.filter(content_type=parent_object_type, object_id=obj)
+            drives_id = Drive.objects.filter(content_type=parent_object_type, object_id=obj.pk)
             partition_dict = {}
             for drive in drives_id:
                 drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
